@@ -48,7 +48,7 @@ class NBApi(FastAPI):
         self.get('/metrics', include_in_schema=False)(metrics)
 
         async def handle_httperror(rec: Request, exc: StarletteHTTPException):
-            logger.error(rec.state, exc)
+            logger.error(rec.state.ctx, exc)
             return JSONResponse(
                 status_code=exc.status_code,
                 content=jsonable_encoder({'status': 'failed', 'code': f'{exc.status_code}'}),
@@ -56,7 +56,7 @@ class NBApi(FastAPI):
         self.exception_handler(StarletteHTTPException)(handle_httperror)
 
         async def auth_error(rec: Request, exc: AuthError):
-            logger.error(rec.state, exc)
+            logger.error(rec.state.ctx, exc)
             return JSONResponse(
                 status_code=401,
                 content=jsonable_encoder({'status': 'failed', 'code': '401'}),
@@ -64,7 +64,7 @@ class NBApi(FastAPI):
         self.exception_handler(AuthError)(auth_error)
 
         async def handle_valueerror(rec: Request, exc: ValueError):
-            logger.error(rec.state, exc)
+            logger.error(rec.state.ctx, exc)
             return JSONResponse(
                 status_code=400,
                 content=jsonable_encoder({'status': 'failed', 'code': '400'}),
@@ -72,7 +72,7 @@ class NBApi(FastAPI):
         self.exception_handler(ValueError)(handle_valueerror)
 
         async def handle_exception(rec: Request, exc: Exception):
-            logger.error(rec.state, exc)
+            logger.error(rec.state.ctx, exc)
             return JSONResponse(
                 status_code=500,
                 content=jsonable_encoder({'status': 'failed', 'code': '500', 'msg': f'{str(exc)}'}),
